@@ -4,8 +4,9 @@ from .chooser import choose
 from .selector import selector
 from .actions import actions
 from .list import List, Scrollbar, ColumnList, Header
+from .core import BlockingInput, NonblockingInput
 
-__version__ = '0.0.5'
+__version__ = '0.0.6'
 __all__ = (
         'Menu',
         'Text',
@@ -16,4 +17,6 @@ __all__ = (
         'Header',
         'selector',
         'actions',
+        'BlockingInput',
+        'NonblockingInput',
         )
