@@ -1,11 +1,11 @@
 import curses
 import math
 
-from curses_toolkit.core import Cbreak
+from curses_toolkit.core import BlockingInput
 
 
 def choose(choices, title=None):
-    with Cbreak():
+    with BlockingInput():
         max_len = max([len(choice) for choice in choices])
         if title:
             max_len = max(max_len, len(title))
