@@ -1,7 +1,7 @@
 import curses
 
 
-class Cbreak:
+class BlockingInput:
     def __enter__(self):
         curses.cbreak()
 
@@ -9,12 +9,12 @@ class Cbreak:
         curses.nocbreak()
 
 
-class NoDelay:
+class NonblockingInput:
     def __init__(self, tenths_sec):
         self.tenths_sec = tenths_sec
 
     def __enter__(self):
-        curses.nodelay(self.tenths_sec)
+        curses.halfdelay(self.tenths_sec)
 
     def __exit__(self, *args):
         curses.nocbreak()
