@@ -18,15 +18,18 @@ class List:
     def add_show_listener(self, listener):
         self.show_listeners.append(listener)
 
-    def show(self):
+    def show(self, ensure_visible=None):
+        visible = (self.focus
+                   if ensure_visible is None
+                   else min(len(self.rows), ensure_visible))
         self.pad.clear()
         for i, row in enumerate(self.rows):
             self.pad.addstr(
                     i, 0, row,
                     curses.A_REVERSE if self.focus == i else curses.A_NORMAL)
-        if self.focus is not None:
+        if visible is not None:
             self.first_visible_row = max(0,
-                                         min(self.focus - int(self.height / 2),
+                                         min(visible - int(self.height / 2),
                                              len(self.rows) - self.height))
         self.pad.refresh(self.first_visible_row, 0,
                          self.row, self.col,
@@ -49,6 +52,9 @@ class List:
             self.pad = curses.newpad(max(height, len(self.rows) + 1),
                                      max(width, len(row) + 1))
 
+    def clear(self):
+        self.rows = []
+
 
 class ColumnList(List):
     def __init__(self, row, col, height, width, column_count, rows=None):
@@ -72,6 +78,11 @@ class ColumnList(List):
                                        for width, col
                                        in zip(self.widths, raw_row)]))
 
+    def clear(self):
+        self.raw_rows = []
+        self.widths = []
+        super().clear()
+
 
 #############
 # listeners #
