@@ -1,10 +1,10 @@
-from curses_toolkit.core import Cbreak
+from curses_toolkit.core import BlockingInput
 
 
 def selector(parent):
     selected = False
     focus = 0
-    with Cbreak():
+    with BlockingInput():
         while not selected:
             focus = parent.set_focus(focus)
             parent.show()
